@@ -27,12 +27,12 @@ class MainHandler(tornado.web.RequestHandler):
     def post(self):
         url = self.request.path[1:]
         if url not in MainHandler.config:
-            return self.write(f"url:{url} not match any service")
+            return self.write("url:{} not match any service".format(url))
         soap = Soap(self.request.body)
         port = soap.port_name()
         ports = MainHandler.config[url]
         if port not in ports:
-            return self.write(f"invalid method {port}")
+            return self.write("invalid method {}".format(port))
         file_path = ports[port]
         with open(file_path, 'r') as f:
             self.set_header( 'Content-Type', 'application/xml charset=utf-8' )
