@@ -45,6 +45,8 @@ class Soap(object):
 class WSDLService(object):
     def __init__(self, wsdl_text):
         self.documents = etree.fromstring(wsdl_text.encode('utf-8') if is_py3 else wsdl_text)
+        self.location = ''
+        self.portName = ''
 
     def bindings(self):
         """
@@ -61,17 +63,17 @@ class WSDLService(object):
             for sub in service_root:
                 if not sub.tag.endswith('port'):
                     continue
-                if sub.attrib['name'].endswith('Soap'):
-                    for addr in sub:
-                        url = addr.attrib['location']
-                        return "/".join(url.split('/')[3:])
+                self.portName = sub.attrib['name']
+                for addr in sub:
+                    url = addr.attrib['location']
+                    self.location = "/".join(url.split('/')[3:])
     
     def ports(self):
         """获取port"""
         for sub in self.documents:
             try:
                 if sub.tag.endswith('portType'):
-                    if sub.attrib['name'].endswith('Soap'):
+                    if sub.attrib['name'] == self.portName:
                         soap_port = sub
             except Exception as e:
                 print(f'{e}')
@@ -81,9 +83,9 @@ class WSDLService(object):
 
     def gen_config(self):
         """生成配置"""
-        access_point = self.bindings()
+        self.bindings()
         config = {
-            access_point:{
+            self.location:{
 
             }
         }
